@@ -11,7 +11,7 @@ except liblo.AddressError as err:
     sys.exit()
 
 # send message "/foo/message1" with int, float and string arguments
-liblo.send(target, "/foo/message1", 123, 456.789, "test")
+liblo.send(target, "/foo/bar", 123, 456.789)
 
 # send double, int64 and char
 liblo.send(target, "/foo/message2", ('d', 3.1415), ('h', 2**42), ('c', 'x'))
